#!/usr/bin/python
#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Chris Lumens <clumens@redhat.com>

import os

from cases import Autopart

class EncryptedAutopartRunner(Autopart.AutopartRunner):
    def writeKickstart(self):
        fo = open("/tmp/kickstart.ks", "w")
        fo.write("autopart --encrypted --passphrase=qweqweqwe\n")
        fo.write("clearpart --all\n")
        fo.write("zerombr")
        fo.close()

class EncryptedAutopartTestCase(Autopart.AutopartTestCase):
    def test_encrypted(self):
        # Check that the PVs making up the autopart VG are all made on top of
        # LUKS devices.
        pvs = self.getDevs(self.state, format="lvmpv")
        self.failIf(len(pvs) == 0, "autopart did not create any physical volumes.")

        for pv in pvs:
            self.assert_(pv["type"] == "luks/dm-crypt",
                         "PV %s was not created as a dm-crypt device" % pv["name"])

    def test_crypttab(self):
        # Encrypted partitioning writes out a /etc/crypttab file.
        self.failIf(not os.path.exists("/etc/crypttab"),
                    "/etc/crypttab does not exist.")

        pvs = self.getDevs(self.state, format="lvmpv")

        with open("/etc/crypttab") as fo:
            for line in fo.readlines():
                stripped = line.strip()
                if stripped.startswith("#"):
                    continue

                (name, device, keyfile) = stripped.split(" ", 3)

                # Every line in /etc/crypttab should refer to a device that
                # was actually created.
                devices = filter(lambda d: d["name"] == name, pvs)
                self.assert_(len(devices) > 0,
                             "/etc/crypttab refers to a name that does not exist: %s" % name)
