#!/bin/bash
# vim: dict=/usr/share/beakerlib/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/bind/Sanity/initscript
#   Description: Init script should meet LSB specifications
#   Author: Jan Scotka <jscotka@redhat.com>, Yulia Kopkova <ykopkova@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2009 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/share/rhts-library/rhtslib.sh
. /usr/share/beakerlib/beakerlib.sh

PACKAGE="bind"

SERVICE=named

PIDFILE="/var/run/named"
LOCKFILE="/var/lock/subsys/named"

rlJournalStart
    
    rlPhaseStartSetup
        rlAssertRpm $PACKAGE
        rlRun "useradd testuserqa" 0 "Add test user"
        rlServiceStop $SERVICE
    rlPhaseEnd
    rlPhaseStartTest "Mandatory actions"
        for ACTION in "start" "stop" "restart" "condrestart" "reload" "force-reload" "status" "usage"; do
            rlRun "grep -i \"usage.*$ACTION\" /etc/init.d/$SERVICE"
        done
    rlPhaseEnd
    rlPhaseStartTest "Start"
        rlRun "service $SERVICE start" 0 " Service must start without problem"
        rlRun "service $SERVICE status" 0 " Then Status command "
        rlRun "service $SERVICE start" 0 " Already started service "
        rlRun "service $SERVICE status" 0 " Again status command "
    rlPhaseEnd
    rlPhaseStartTest "Restart"
        rlRun "service $SERVICE restart" 0 " Restarting of service"
        rlRun "service $SERVICE status" 0 " Status command "
    rlPhaseEnd
    rlPhaseStartTest "Stop"
        rlRun "service $SERVICE stop" 0 " Stopping service "
        rlRun "service $SERVICE status" 3 " Status of stopped service "
        rlRun "service $SERVICE stop" 0 " Stopping service again "
        rlRun "service $SERVICE status" 3 " Status of stopped service "
    rlPhaseEnd
    rlPhaseStartTest "LOCK file"
        touch $LOCKFILE
        rlRun "service $SERVICE status" 2 "Existing lock file, but service not started"
        rlRun "rm -fv $LOCKFILE" 0 "Remove Lock file"
        rlRun "service $SERVICE status" 3 "Service should look stopped"
        rlRun "service $SERVICE start" "Starting service"
        rlAssertExists "$LOCKFILE" "Lock file $LOCKFILE must exist"
        rlRUn "service $SERVICE stop" "Stopping service"
    rlPhaseEnd
    rlPhaseStartTest "PID file"
        touch $PIDFILE
        rlRun "service $SERVICE status" 1 "Existing pid file, but service not started"
        rlRun "rm -fv $PIDFILE" 0 "Remove .pid file"
        rlRun "service $SERVICE status" 3 "Service should look stopped"
        rlRun "service $SERVICE start" "Starting service"
        rlAssertExists "$PIDFILE" "Pid file $PIDFILE must exist"
        rlRUn "service $SERVICE stop" "Stopping service"
    rlPhaseEnd
    rlPhaseStartTest "Insufficient rights"
        rlRun "service $SERVICE start " 0 " Starting service for restarting under nonpriv user "
        rlRun "su testuserqa -c 'service $SERVICE restart'" 1,4 "Insufficient rights, restarting service under nonprivileged user must fail"
    rlPhaseEnd
    rlPhaseStartTest "Operation"
        rlRun "service $SERVICE start" 0 " Service have to implement start function "
        rlRun "service $SERVICE restart" 0 " Service have to implement restart function "
        rlRun "service $SERVICE status" 0 " Service have to implement status function "
        rlRun "service $SERVICE condrestart" 0 " Service have to implement condrestart function "
        rlRun "service $SERVICE try-restart" 0 " Service have to implement try-restart function "
        rlRun "service $SERVICE reload" 0 " Service have to implement reload function "
        rlRun "service $SERVICE force-reload" 0 " Service have to implement force-reload function "
    rlPhaseEnd
    rlPhaseStartTest "Nonexist operations"
        rlRun "service $SERVICE noexistop" 2 " Testing proper return code when nonexisting function"
    rlPhaseEnd

    rlPhaseStartCleanup
        rlServiceRestore $SERVICE
        rlRun "userdel -fr testuserqa" 0 "Remove test user"
    rlPhaseEnd

rlJournalPrintText
rlJournalEnd
