#!/bin/bash
# vim: dict=/usr/share/rhts-library/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/cups/Sanity/init-script-LSB
#   Description: Init script should meet LSB specifications
#   Author: Vojtech Aschenbrenner <vaschenb@redhat.com>
#           Jan Scotka <jscotka@redhat.com>
#           Yulia Kopkova <ykopkova@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2009 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/share/rhts-library/rhtslib.sh
. /usr/share/beakerlib/beakerlib.sh

PACKAGE="cups"

SERVICE=$PACKAGE
DAEMON=cupsd

rlJournalStart
    
    rlPhaseStartSetup
        rlAssertRpm $PACKAGE
        rlRun "useradd testuserqa" 0 "Add test user"
        rlServiceStop $SERVICE
    rlPhaseEnd

    rlPhaseStartTest "Recognized actions"
        USAGE_FILE=`mktemp`
        CASE_FILE=`mktemp`
        LINES_COUNT=`wc -l < /etc/init.d/$SERVICE`
        LAST_CASE=`grep -n case /etc/init.d/$SERVICE | tail -n 1 | cut -d ':' -f 1`
        rlRun "tail -n $((LINES_COUNT - LAST_CASE)) /etc/init.d/$SERVICE | grep '[ \t]*[|a-zA-Z-]*)' | cut -d ')' -f 1 | tr '|' '\n' | tr -d ' \t' | grep -v '*' | sort > $CASE_FILE"
        rlRun "grep -i usage /etc/init.d/$SERVICE | cut -d '{' -f 2 | tr -d '}\"' | tr '|' '\n' | sort > $USAGE_FILE"
        rlRun "diff $CASE_FILE $USAGE_FILE"
        rm -f $USAGE_FILE
        rm -f $CASE_FILE
    rlPhaseEnd

    rlPhaseStartTest

        rlLog ">>>>>>>>> service start"
        rlRun "service $SERVICE start" 0 " Service must start without problem"
        rlRun "service $SERVICE status" 0 " Then Status command "
        rlRun "service $SERVICE start" 0 " Already started service "
        rlRun "service $SERVICE status" 0 " Again status command "

        rlLog ">>>>>>>>> service restart"
        rlRun "service $SERVICE restart" 0 " Restarting of service"
        rlRun "service $SERVICE status" 0 " Status command "

        rlLog ">>>>>>>>> service stop"
        rlRun "service $SERVICE stop" 0 " Stopping service "
        rlRun "service $SERVICE status" 3 " Status of stopped service "
        rlRun "service $SERVICE stop" 0 " Stopping service again "
        rlRun "service $SERVICE status" 3 " Status of stopped service "


        rlLog ">>>>>>>>> pid file"
        rlServiceStart $SERVICE
        rlAssertExists "/var/run/$DAEMON.pid" "Pid file /var/run/$DAEMON.pid must exist"
        rlRun "killall $DAEMON" 0 "Kill $SERVICE"
        rlRun "service $SERVICE status" 1 " Existing pid file, but service not started "
        rlRun "rm -fv /var/run/$DAEMON.pid" 0 "Remove .pid file"
        
        rlLog ">>>>>>>>> lock file"
        rlRun "service $SERVICE status" 2 " Existing lock file, but service not started "
        rlServiceStop $SERVICE

        rlLog ">>>>>>>>> insufficient rights"
        rlRun "service $SERVICE start " 0 " Starting service for restarting under nonpriv user "
        rlRun "su testuserqa -c 'service $SERVICE restart'" 4 "Insufficient rights, restarting service under nonprivileged user must fail"

        rlLog ">>>>>>>>> operations"
        rlRun "service $SERVICE start" 0 " Service have to implement start function "
        rlRun "service $SERVICE restart" 0 " Service have to implement restart function "
        rlRun "service $SERVICE restartlog" 0 " Service have to implement restartlog function "
        rlRun "service $SERVICE status" 0 " Service have to implement status function "
        rlRun "service $SERVICE condrestart" 0 " Service have to implement condrestart function "
        rlRun "service $SERVICE try-restart" 0 " Service have to implement try-restart function "
        rlRun "service $SERVICE reload" 0 " Service have to implement reload function "
        rlRun "service $SERVICE force-reload" 0 " Service have to implement force-reload function "

        rlLog ">>>>>>>>> nonexist operations"
        rlRun "service $SERVICE noexistop" 2 " Testing proper return code when nonexisting function"

    rlPhaseEnd

    rlPhaseStartCleanup
        rlServiceRestore $SERVICE
        rlRun "userdel -fr testuserqa" 0 "Remove test user"
    rlPhaseEnd

rlJournalPrintText
rlJournalEnd
