#!/bin/bash
# vim: dict=/usr/share/beakerlib/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/mysql-server/Sanity/init-script-LSB
#   Description: Test initscript sanity
#   Author: Martin Cermak <mcermak@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2010 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/lib/beakerlib/beakerlib.sh
. /usr/share/beakerlib/beakerlib.sh

PACKAGE="mysql-server"
SERVICE=mysqld

function myRlRun () {
    rlRun "$1" "$2" "$3"
    #echo Hit Enter...
    #read
}


rlJournalStart
    rlPhaseStartSetup
        adduser testuserqa
        rlServiceStop "$SERVICE"
    rlPhaseEnd

    rlPhaseStartTest

    rlLog ">>>>>>>>> service start"
      myRlRun "service $SERVICE start" 0 " Service must start without problem"
      myRlRun "service $SERVICE status" 0 " Then Status command "    
      # see https://bugzilla.redhat.com/show_bug.cgi?id=562742
      # myRlRun "service $SERVICE start" 0 " Already started service "    
      myRlRun "service $SERVICE status" 0 " Again status command "    

    rlLog ">>>>>>>>> service restart"
      myRlRun "service $SERVICE restart" 0 " Restarting of service"
      myRlRun "service $SERVICE status" 0 " Status command "    

    rlLog ">>>>>>>>> service stop"
      myRlRun "service $SERVICE stop" 0 " Stopping service "
      myRlRun "service $SERVICE status" 3 " Status of stopped service "
      myRlRun "service $SERVICE stop" 0 " Stopping service again "    
      myRlRun "service $SERVICE status" 3 " Status of stopped service "

    rlLog ">>>>>>>>> pid file"
      service $SERVICE start  
      rlAssertExists "/var/run/$SERVICE/$SERVICE.pid" "Pid file /var/run/$SERVICE/$SERVICE.pid must exist"
      service $SERVICE stop    
      myRlRun "touch /var/run/$SERVICE/$SERVICE.pid" 
      myRlRun "service $SERVICE status" 1 " Existing pid file, but service not started "  
      service $SERVICE stop    
      rm -rf /var/run/$SERVICE/$SERVICE.pid

    rlLog ">>>>>>>>> lock file"
      service $SERVICE start   
      rlAssertExists "/var/lock/subsys/$SERVICE" "Lock file /var/lock/subsys/$SERVICE must exist"
      service $SERVICE stop    
      myRlRun "touch /var/lock/subsys/$SERVICE"    
      myRlRun "service $SERVICE status" 2 " Existing lock file, but service not started "    
      service $SERVICE stop    
      rm -fv /var/lock/subsys/$SERVICE    


    rlLog ">>>>>>>>> insufficient rights"
      myRlRun "service $SERVICE start " 0 " Starting service for restarting under nonpriv user "
      myRlRun "su testuserqa -c 'service $SERVICE restart'" 0 "Insufficient rights, restarting resrvice under nonprivileged user must fail"

    rlLog ">>>>>>>>> operations"
      # see https://bugzilla.redhat.com/show_bug.cgi?id=562742
      # myRlRun "service $SERVICE start" 0 " Service have to implement start function "
      myRlRun "service $SERVICE restart" 0 " Service have to implement restart function "
      myRlRun "service $SERVICE status" 0 " Service have to implement status function "
      myRlRun "service $SERVICE usage" 0,3,2 " Service have to implement usage function "
      myRlRun "service $SERVICE condrestart" 0,3 " Service have to implement condrestart function "
      myRlRun "service $SERVICE try-restart" 0,3 " Service have to implement try-restart function "
      myRlRun "service $SERVICE reload" 0,3 " Service have to implement reload function "
      myRlRun "service $SERVICE force-reload" 0,3 " Service have to implement force-reload function "

    rlLog ">>>>>>>>> nonexist operations"
      myRlRun "service $SERVICE noexistop" 2 " Testing proper return code when nonexisting function"

    rlLog ">>>>>>>>> invalid arguments"
      myRlRun "service $SERVICE" 2 " When no arguments added to service, it must fail with proper return code "
    
    rlPhaseEnd

    rlPhaseStartCleanup 
	userdel testuserqa
        rlServiceRestore "$SERVICE"
    rlPhaseEnd

#rlJournalPrintText
rlJournalEnd

