#!/bin/bash
# vim: dict=/usr/share/rhts-library/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/openssh/Sanity/init-scripts-LSB
#   Description: init scripts must meet LSB specifications
#   Author: Milos Malik <mmalik@redhat.com>
#   Author: Miroslav Vadkerti <mmvadkert@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2009 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
#. /usr/bin/rhts-environment.sh
#. /usr/share/rhts-library/rhtslib.sh
. /usr/share/beakerlib/beakerlib.sh


PACKAGE="openssh"
SERVICE="sshd"

rlJournalStart
    rlPhaseStartSetup
        rlAssertRpm $PACKAGE
        USAGE_FILE=`mktemp`
        CASE_FILE=`mktemp`
        rlServiceStop $SERVICE
    rlPhaseEnd

    rlPhaseStartTest "Mandatory actions"
        for ACTION in "start" "stop" "restart" "force-reload" "status" ; do
            rlRun "grep -i \"usage.*$ACTION\" /etc/init.d/$SERVICE"
        done
    rlPhaseEnd

    rlPhaseStartTest "Recognized actions"
        LINES_COUNT=`wc -l < /etc/init.d/$SERVICE`
        LAST_CASE=`grep -n case /etc/init.d/$SERVICE | tail -n 1 | cut -d ':' -f 1`
        rlRun "tail -n $((LINES_COUNT - LAST_CASE)) /etc/init.d/$SERVICE | grep '[ 	]*[|a-zA-Z-]*)' | cut -d ')' -f 1 | tr '|' '\n' | tr -d ' 	' | grep -v '*' | grep -v '\\$' | sed 's/\t//g' | sort > $CASE_FILE"
        rlRun "grep -i usage /etc/init.d/$SERVICE | cut -d '{' -f 2 | tr -d '}\"' | tr '|' '\n' | sort > $USAGE_FILE"
        rlRun "diff $CASE_FILE $USAGE_FILE"
    rlPhaseEnd

    rlPhaseStartTest "Start"
        rlRun "service $SERVICE start" 0
        rlRun "service $SERVICE status" 0
        rlRun "service $SERVICE start" 0
        rlRun "service $SERVICE status" 0
        rlRun "service $SERVICE restart" 0
        rlRun "service $SERVICE status" 0
    rlPhaseEnd

    rlPhaseStartTest "Stop"
        rlRun "service $SERVICE stop" 0
        rlRun "service $SERVICE status" 3
        rlRun "service $SERVICE stop" 0
        rlRun "service $SERVICE status" 3
    rlPhaseEnd

    rlPhaseStartTest "Lock file"
        rlRun "touch /var/lock/subsys/$SERVICE"
        rlRun "service $SERVICE status" 2
        rlRun "rm -rf /var/lock/subsys/$SERVICE" 
    rlPhaseEnd

    rlPhaseStartTest "PID file"
        rlRun "touch /var/run/$SERVICE.pid"
        rlRun "service $SERVICE status" 1
        rlRun "rm -rf /var/run/$SERVICE.pid"
    rlPhaseEnd

    rlPhaseStartTest "Condrestart"
        rlRun "service $SERVICE start" 0
        rlRun "service $SERVICE condrestart" 0
        rlRun "service $SERVICE status" 0
    rlPhaseEnd

    rlPhaseStartCleanup
        rm -f $USAGE_FILE
        rm -f $CASE_FILE
        rlServiceRestore $SERVICE
    rlPhaseEnd
rlJournalPrintText
rlJournalEnd

