# Makefile - init-script-exit-codes
# Author: Ales Zelinka <azelinka@redhat.com>
# Location: /CoreOS/samba/Regression/init-script-exit-codes/Makefile

# Description: checks initscripts of samba daemons

# Copyright (c) 2008 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or
# redistribute it subject to the terms and conditions of the GNU General
# Public License v.2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.


PACKAGE=samba

NAME=`basename $TEST`

# Include rhts environment
#. /usr/share/rhts-library/rhtslib.sh
#. /usr/bin/rhts-environment.sh
. /usr/share/beakerlib/beakerlib.sh

rlJournalStart
rlPhaseStartSetup Setup
    rlAssertRpm $PACKAGE
rlPhaseEnd

for SERVICE in smb nmb winbind  ; do
    if ! chkconfig --list $SERVICE ; then
        rlLogError "service $SERVICE doesn't exist"
        continue
    fi
rlPhaseStartSetup Setup-$SERVICE
    #stop it to have consistent starting position
    rlServiceStop $SERVICE
    sleep 2
rlPhaseEnd

rlPhaseStartTest Test-$SERVICE-start-stop
    ps -A |grep -v grep |grep ${SERVICE}d ; rlAssertNotEquals "$SERVICE processes not running before startup" $? 0
    rlRun "service $SERVICE start" 0 "service $SERVICE start returns 0"
    sleep 5
    ps -A |grep -v grep |grep ${SERVICE}d ; rlAssert0 "$SERVICE processes running after start" $?
    sleep 2
    rlRun "service $SERVICE status" 0 "service $SERVICE status reported as running" $?
    rlRun "service $SERVICE start" 0 "service $SERVICE 2nd start returns 0"
    rlRun "service $SERVICE status" 0 "service $SERVICE status still reported as running" $?
    sleep 2
    rlRun "service $SERVICE stop" 0 "service $SERVICE stop returns 0"
    sleep 20
    rlRun "service $SERVICE status" 3 "service $SERVICE status reported as stopped (ECODE 3)" $?
    sleep 2
    #this fails on rhel4 but is not serious enough to fix - skipping for this test to remain useful
    rlIsRHEL 4 ||rlRun "service $SERVICE stop" 0 "service $SERVICE 2nd stop returns 0"
    sleep 2
    rlRun "service $SERVICE status" 3 "service $SERVICE status still reported as stopped (ECODE 3)" $?
    sleep 2
    ps -A |grep -v grep |grep ${SERVICE}d ; rlAssertNotEquals "no processes running for service $SERVICE" 0 $?
    rlRun "service $SERVICE start" 0
    sleep 5
rlPhaseEnd
rlPhaseStartTest Test-$SERVICE-restart-condrestart
    SERVICE_PID_A=`cat /var/run/${SERVICE}d.pid`
    rlLog "service $SERVICE PID: $SERVICE_PID" SERVICE
    rlRun "service $SERVICE restart" 0 "service $SERVICE restart returns 0"
    sleep 5
    SERVICE_PID_B=`cat /var/run/${SERVICE}d.pid`
    rlRun "[ \"$SERVICE_PID_A\" -ne \"$SERVICE_PID_B\" ] " 0 " PID of service $SERVICE changed during restart"
    rlRun "service $SERVICE status" 0 "service $SERVICE status reported as running" $?
    rlRun "service $SERVICE condrestart" 0 "service $SERVICE condrestart returns 0"
    sleep 5
    SERVICE_PID_A=`cat /var/run/${SERVICE}d.pid`
    rlRun "[ \"$SERVICE_PID_A\" -ne \"$SERVICE_PID_B\" ] " 0 " PID of service $SERVICE changed during condrestart"
    rlRun "service $SERVICE status" 0 "service $SERVICE status reported as running" $?
    sleep 2
rlPhaseEnd

#only as part of rhel6/Fedora LSB compliance
if rlIsRHEL 6 || rlIsFedora ; then
rlPhaseStartTest Test-$SERVICE-pidfile-lockfile
    #force kill the daemons and check if status reports it correctly
    rlRun "killall -9 ${SERVICE}d " 0 "Killing service $SERVICE"
    rlRun "service $SERVICE status" 1 "service $SERVICE status reports dead service but existing pidfile (ECODE 1)" $?
    rlRun "service $SERVICE start" 0
    sleep 5
    #kill the daemons and check if status reports it correctly
    rlRun "[ -f /var/lock/subsys/$SERVICE ]" 0 "subsystem lockfile exists"
    rlRun "killall ${SERVICE}d " 0 "Killing service $SERVICE"
    rlRun "service $SERVICE status" 2 "service $SERVICE status reports dead service but existing subsys lock(ECODE 2)" $?
    sleep 2
rlPhaseEnd
fi

rlPhaseStartCleanup CleanUp-$SERVICE
    service $SERVICE restart
    rlServiceRestore $SERVICE
rlPhaseEnd

done
rlJournalEnd
rlJournalPrintText

